@@ -1,19 +1,7 @@
 ;;; org-node-changes.el --- Help user transit renamed user options -*- lexical-binding: t; -*-
 
 ;; Copyright (C) 2024-2026 Martin Edström
-;;
-;; This file is free software; you can redistribute it and/or modify
-;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 3, or (at your option)
-;; any later version.
-;;
-;; This program is distributed in the hope that it will be useful,
-;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;; GNU General Public License for more details.
-;;
-;; For a full copy of the GNU General Public License
-;; see <http://www.gnu.org/licenses/>.
+;; SPDX-License-Identifier: GPL-3.0-or-later
 
 ;;; Commentary:
 
@@ -35,22 +23,17 @@
 (defvar org-node-major-version 3
   "Number incremented for breaking changes that require reading README.")
 
-(defmacro org-node-changes--def-whiny-alias
-    (old new when removed-by &optional interactive)
+(defmacro org-node-changes--def-whiny-alias (old new when removed-by)
   "Define function OLD as effectively an alias for NEW.
-Also, running OLD will emit a deprecation warning the first time.
-
-If INTERACTIVE, define it as an interactive function.  Optional
-string WHEN says when it was deprecated and REMOVED-BY when it
-may be removed.  When these strings are omitted, fall back on
-hardcoded strings."
+Also, calling OLD will emit a deprecation warning the first time.
+String WHEN says when it was deprecated and REMOVED-BY when it
+may be removed from the package."
   `(let (warned-once)
      (defun ,(cadr old) (&rest args)
        (declare (obsolete ,(cadr new) ,when))
-       ,@(if interactive '((interactive)))
        (unless warned-once
          (setq warned-once t)
-         (lwarn ,old :warning "Obsolete as of %s, will be removed by %s; use `%s' instead. (Check your initfiles)"
+         (lwarn ,old :warning "Obsolete as of %s, will be removed by %s; use `%s' instead. "
                 ,when ,removed-by ,new))
        (apply ,new args))))
 
@@ -75,7 +58,7 @@ hardcoded strings."
 (require 'org-mem-updater)
 
 (if (or (not (boundp 'org-mem-internal-version))
-        (< org-mem-internal-version 27))
+        (< org-mem-internal-version 39))
     (display-warning 'org-node "Update org-mem to use this version of org-node"))
 
 (org-node-changes--def-whiny-alias 'org-node--goto                      'org-node-goto                         "3.8.0 (July 2025)" "May 2026")
@@ -88,6 +71,8 @@ hardcoded strings."
 (org-node-changes--def-whiny-alias 'org-node-sort-by-crtime             'org-node-sort-by-crtime-property      "3.11.1 (December 2025)" "July 2026")
 (org-node-changes--def-whiny-alias 'org-node-sort-by-crtime-cheap       'org-node-sort-by-crtime-property      "3.11.1 (December 2025)" "July 2026")
 (org-node-changes--def-whiny-alias 'org-node-sort-by-mtime-cheap        'org-node-sort-by-mtime-property       "3.11.1 (December 2025)" "July 2026")
+(org-node-changes--def-whiny-alias 'org-node--get-filetags              'org-node-get-tags-here                "2026-03-01" "August 2026")
+(org-node-changes--def-whiny-alias 'org-node--kill-blank-unsaved-buffers 'org-node-seq--kill-blank-unsaved-buffers  "2026-03-01" "August 2026")
 
 (provide 'org-node-changes)
 
