@@ -1,18 +1,7 @@
 ;;; org-node-context.el ---  -*- lexical-binding: t; -*-
+
 ;; Copyright (C) 2025-2026 Martin Edström
-
-;; This program is free software: you can redistribute it and/or modify
-;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation, either version 3 of the License, or
-;; (at your option) any later version.
-
-;; This program is distributed in the hope that it will be useful,
-;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-;; GNU General Public License for more details.
-
-;; You should have received a copy of the GNU General Public License
-;; along with this program. If not, see <http://www.gnu.org/licenses/>.
+;; SPDX-License-Identifier: GPL-3.0-or-later
 
 ;;; Commentary:
 
@@ -445,7 +434,7 @@ else briefly visit the file, go to the link and call
         (with-current-buffer (org-node--work-buffer-for (org-mem-file entry))
           (goto-char link-pos)
           (setq snippet (org-node-context--extract-entry-at-point)))
-        (with-current-buffer (org-mem-org-mode-scratch)
+        (with-current-buffer (org-mem-scratch)
           (erase-buffer)
           (insert snippet)
           (goto-char pos-diff)
