@@ -1,19 +1,7 @@
 ;;; org-node-seq.el --- Experimental way to define node sequences -*- lexical-binding: t; -*-
 
 ;; Copyright (C) 2024-2026 Martin Edström
-;;
-;; This program is free software: you can redistribute it and/or modify
-;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation, either version 3 of the License, or
-;; (at your option) any later version.
-;;
-;; This program is distributed in the hope that it will be useful,
-;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-;; GNU General Public License for more details.
-;;
-;; You should have received a copy of the GNU General Public License
-;; along with this program. If not, see <http://www.gnu.org/licenses/>.
+;; SPDX-License-Identifier: GPL-3.0-or-later
 
 ;;; Commentary:
 
@@ -46,7 +34,7 @@
 (declare-function org-entry-get-with-inheritance "org")
 (declare-function org-up-heading-or-point-min "org")
 
-;;; Easy wrappers to define a sequence
+;;;; Easy wrappers to define a sequence
 
 ;;;###autoload
 (defun org-node-seq-def-on-any-sort-by-property
@@ -156,7 +144,7 @@ YYYY-MM-DD format, e.g. \"2024-01-31.org\"."
                            (sortstr (file-name-base path)))
                       (cons sortstr path))))
     :whereami (lambda ()
-                (let ((file-name (org-mem--truename-maybe buffer-file-name)))
+                (let ((file-name (org-mem-file-known-p buffer-file-name)))
                   (when (string-prefix-p ,dir file-name)
                     (file-name-base file-name))))
     :prompter (lambda (key)
@@ -173,7 +161,7 @@ YYYY-MM-DD format, e.g. \"2024-01-31.org\"."
                  (org-node-create sortstr (org-id-new) key)))))
 
 
-;;; Helpers to use in a seq definition
+;;;; Helpers to use in a seq definition
 
 ;;;###autoload
 (defun org-node-seq-try-goto-id (id)
@@ -382,9 +370,37 @@ nothing."
                 (lambda (item1 item2)
                   (string> (car item1) (car item2)))))))))
 
+;; TODO: Could the :creator just check if the buffer is unmodified and empty?
+;;       But possible pitfall that the user may have important stuff in undo.
+(defun org-node-seq--kill-blank-unsaved-buffers (&rest _)
+  "Kill buffers created by org-node that have always been blank.
+
+This exists to allow you to create a node, especially a journal note for
+today via package \"org-node-seq\", change your mind, do an `undo' to
+empty the buffer, then browse to the previous day\\='s note.  When later
+you want to create today\\='s note after all, the seq\\='s :creator
+function should be made to run again, but it will not do so if the
+buffer already exists, so the buffer stays blank.  Thus this hook."
+  (unless (minibufferp)
+    (dolist (buf org-node--new-unsaved-buffers)
+      (if (or (not (buffer-live-p buf))
+              (file-exists-p (buffer-file-name buf)))
+          ;; Stop checking the buffer
+          (setq org-node--new-unsaved-buffers
+                (delq buf org-node--new-unsaved-buffers))
+        (with-current-buffer buf
+          (when (and (not (get-buffer-window buf t))
+                     (not (buffer-modified-p))
+                     (string-blank-p (buffer-string)))
+            (when buffer-auto-save-file-name
+              ;; Hopefully throw away a stale autosave
+              ;; since its existence annoys the user on re-creating the file
+              (do-auto-save nil t))
+            (kill-buffer buf)))))))
+
 (defun org-node-seq--jump (key)
   "Prompt for and jump to an entry in node seq identified by KEY."
-  (org-node--kill-blank-unsaved-buffers)
+  (org-node-seq--kill-blank-unsaved-buffers)
   (require 'org)
   (let* ((seq (cdr (assoc key org-node-seqs)))
          (sortstr (funcall (plist-get seq :prompter) key))
@@ -451,7 +467,7 @@ Unlike `org-node-proposed-seq', does not need to revert to nil.")
 (defun org-node-seq-capture-target ()
   "Experimental."
   (org-node-cache-ensure)
-  (org-node--kill-blank-unsaved-buffers)
+  (org-node-seq--kill-blank-unsaved-buffers)
   (let ((key (or org-node-seq--current-key
                  (let* ((valid-keys (mapcar #'car org-node-seq-defs))
                         (elaborations
@@ -623,6 +639,9 @@ not exist."
                     (format " + %.2fs caching org-node-seqs"
                             (float-time (time-since T))))))))
 
+
+;;;; Transient menu
+
 (defun org-node-seq--add-to-dispatch (key name)
   "Use KEY and NAME to add a sequence to the Transient menu."
   (when (ignore-errors (transient-get-suffix 'org-node-seq-dispatch key))
